@@ -58,7 +58,8 @@ ResourceNotFound = restkit.ResourceNotFound
 class CouchdbResource(restkit.Resource):
 
     def __init__(self, uri="http://127.0.0.1:5984", transport=None, 
-            use_proxy=False, min_size=0, max_size=4, pool_class=None, **kwargs):
+            use_proxy=False, min_size=0, max_size=4, timeout=300,
+            pool_class=None, **kwargs):
         """Constructor for a `CouchdbResource` object.
 
         CouchdbResource represent an HTTP resource to CouchDB.
@@ -73,19 +74,20 @@ class CouchdbResource(restkit.Resource):
                 or make your own depending on the options you need to access the 
                 server (authentification, proxy, ....).
         @param use_proxy: boolean, default is False, if you want to use a proxy
+        @param timeout: connection timeour, delay after a connection should be released
         @param min_size: minimum number of connections in the pool
         @param max_size: maximum number of connection in the pool
         @param pool_class: custom pool class
         """
         
         restkit.Resource.__init__(self, uri=uri, transport=transport, 
-                use_proxy=use_proxy, min_size=min_size, max_size=max_size, 
-                pool_class=pool_class)
+                use_proxy=use_proxy, timeout=timeout, min_size=min_size, 
+                max_size=max_size, pool_class=pool_class)
         self.client.safe = ":/%"
 
     def clone(self):
         obj = self.__class__(uri=self.uri, transport=self.transport,
-                use_proxy=self.use_proxy, min_size=self.min_size, 
+                use_proxy=self.use_proxy, timeout=self.timeout, min_size=self.min_size, 
                 max_size=self.max_size, pool_class=self.pool_class)
         return obj
         
